@@ -5,7 +5,7 @@
 ;; Author: Oscar Figueiredo <Oscar.Figueiredo@epfl.ch>
 ;; Maintainer: Oscar Figueiredo <Oscar.Figueiredo@epfl.ch>
 ;; Created: Feb 1998
-;; Version: $Revision: 1.7 $
+;; Version: $Revision: 1.8 $
 ;; Keywords: help
 
 ;; This file is part of XEmacs
@@ -93,7 +93,10 @@ Supported protocols are specified by `eudc-supported-protocols'."
   "*A list of the default attributes to extract from directory entries.
 If set to the symbol `all' return all attributes.
 nil means return the default attributes as configured in the server."
-  :type  '(repeat (symbol :tag "Field name"))
+  :type  '(choice :menu-tag "Return Attributes"
+		  (const :menu-tag "Server Defaults (nil)" nil)
+		  (const :menu-tag "All" all)
+		  (repeat :menu-tag "Edit List" (symbol :tag "Field name")))
   :group 'eudc)
 
 (defcustom eudc-multiple-match-handling-method 'select
@@ -398,10 +401,13 @@ defaulting to `eudc-default-return-attributes'."
    (unless eudc-query-function
      (error "Don't know how to perform the query"))
    (if no-translation
-       (funcall eudc-query-function query return-attributes)
+       (funcall eudc-query-function query (or return-attributes
+					      eudc-default-return-attributes))
+		
      (funcall eudc-query-function 
 	      (eudc-translate-query query)
-	      (eudc-translate-attribute-list return-attributes))))
+	      (eudc-translate-attribute-list (or return-attributes
+						 eudc-default-return-attributes)))))
 
  
 (defun eudc-display-records (records &optional raw-attr-names)
@@ -557,6 +563,21 @@ otherwise they are formatted according to `eudc-user-attribute-names-alist'."
 	      duplicates)
       result)))
           
+(defun eudc-filter-partial-records (records attrs)
+  "Eliminate records that do not caontain all ATTRS from RECORDS."
+  (delq nil 
+	(mapcar 
+	 (function 
+	  (lambda (rec)
+	    (if (eval (cons 'and 
+		       (mapcar 
+			(function 
+			 (lambda (attr)
+			   (consp (assq attr rec))))
+			attrs)))
+		rec)))
+	 records)))
+	   
 (defun eudc-add-field-to-records (field records)
   "Add FIELD to each individual record in RECORDS and return the resulting list."
   (mapcar (function
